==============================================
``psyclone.tests.core.component_indices_test``
==============================================

.. automodule:: psyclone.tests.core.component_indices_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.core.component_indices_test
